# Project governance

The project is governed by a committee of maintainers who collectively decide the direction of the project with input from the community. A list of the current maintainers is available in the [README](README.md).

## Maintainer responsibilities

Maintainers are people who care about the project and are responsible for helping it grow and improve. Maintainers must contribute to the project, as well as help review contributions from the community. Maintainers must also work collaboratively with each other.

Maintainers have write access to this repository. Maintainers can merge their own contributions or contributions from others. Nevertheless, maintainers are encouraged to seek review from each other, particularly for significant changes.

## Becoming a Maintainer

To become a maintainer you need to demonstrate the following:

* Participation in project discussions
* Contribution of significant pull requests
* Ability to write quality code, tests, examples, and/or documentation
* Ability to collaborate with the maintainers
* Understanding of the project's goals, organization, and conventions

Prospective maintainers can request maintainer privileges by sending a message to the current maintainers at info@biosimulators.org.

## Project meetings

Maintainers are expected to participate in the project's meetings, which occur online at 11am EST on Thursdays. Other members of the community are also welcome to attend the project's meetings to provide input and feedback on the project. Please contact the maintainers at info@biosimulators.org for the link for the project meetings.
